Module obs

Module obs 

Short business-facing name for Saddle Observability.

Structs

DomainEvent
An explicit business event associated with the current call context.

Enums

DomainEventError
Validation failures for bounded V1 domain events.
DomainValue
Scalar domain data that is safe and intentional to include in a log event.
EventLevel
Stable severity values emitted by Saddle’s JSON logger.

Functions

record
Records one bounded domain event on the current Saddle call context.