pub enum DomainValue {
String(String),
Signed(i64),
Unsigned(u64),
Bool(bool),
}Expand description
Scalar domain data that is safe and intentional to include in a log event.
Arbitrary object serialization is deliberately unsupported so callers do not accidentally log full requests, responses or domain entities.
Variants