pub fn record(context: &CallContext, event: DomainEvent) -> Result<()>Expand description
Records one bounded domain event on the current Saddle call context.
pub fn record(context: &CallContext, event: DomainEvent) -> Result<()>Records one bounded domain event on the current Saddle call context.