pub struct ListenerAuthoritySeal { /* private fields */ }Expand description
One-shot facade seal for the independent listener authority provider.
Implementations
Sourceimpl ListenerAuthoritySeal
impl ListenerAuthoritySeal
Sourcepub fn bind_verified(
self,
bundle_identity: [u8; 32],
nonce_identity: [u8; 32],
binary_identity: [u8; 32],
deployment_identity: [u8; 32],
calibration_identity: [u8; 32],
) -> Result<VerifiedListenerAuthority>
pub fn bind_verified( self, bundle_identity: [u8; 32], nonce_identity: [u8; 32], binary_identity: [u8; 32], deployment_identity: [u8; 32], calibration_identity: [u8; 32], ) -> Result<VerifiedListenerAuthority>
Binds an independently verified listener authority to the exact signed bundle/nonce/executable/deployment/calibration tuple.