pub struct ProductionLauncher { /* private fields */ }Expand description
Opaque, non-Clone permission to start the sole production assembly.
ⓘ
fn replay(launcher: &ProductionLauncher) {
let _copy = (*launcher).clone();
}ⓘ
let _forged = ProductionLauncher { deployment: () };The public launch shape has no deployment third parameter:
fn launch<B, O>(bundle: B, config: SaddleConfig, generated: O) -> Result<()>
where
B: ApprovedExternalBundle,
O: GeneratedApplicationOwner,
{
ProductionLauncher::verify(bundle)?.run(config, generated)
}Implementations
Sourceimpl ProductionLauncher
impl ProductionLauncher
Sourcepub fn verify<B>(
bundle: B,
) -> Result<VerifiedProductionLauncher<B::Reservation, B::Authority>>where
B: ApprovedExternalBundle,
pub fn verify<B>(
bundle: B,
) -> Result<VerifiedProductionLauncher<B::Reservation, B::Authority>>where
B: ApprovedExternalBundle,
Consumes the sole approved external bundle. Failure occurs before the deployment owner reaches Observer, DB, Tokio or listener construction.