SaddleError

Struct SaddleError 

pub struct SaddleError { /* private fields */ }
An error safe to propagate across Saddle component boundaries.

message must not contain credentials, SQL parameters, request payloads or other sensitive implementation details.

Implementations

Source

impl SaddleError

pub fn new( kind: ErrorKind, code: &'static str, message: impl Into<String>, ) -> SaddleError

pub const fn kind(&self) -> ErrorKind

pub const fn code(&self) -> &'static str

pub fn message(&self) -> &str