Short business-facing name for Saddle Observability.
Structs
- Domain
Event - An explicit business event associated with the current call context.
Enums
- Domain
Event Error - Validation failures for bounded V1 domain events.
- Domain
Value - Scalar domain data that is safe and intentional to include in a log event.
- Event
Level - Stable severity values emitted by Saddle’s JSON logger.
Functions
- record
- Records one bounded domain event on the current Saddle call context.